@@ -1,4 +1,4 @@
-# Copyrights 2001-2020 by [Mark Overmeer <markov@cpan.org>].
+# Copyrights 2001-2021 by [Mark Overmeer <markov@cpan.org>].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
 # Pod stripped from pm file by OODoc 2.02.
@@ -8,7 +8,7 @@
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '3.010';
+$VERSION = '3.011';
 
 
 use strict;
@@ -30,12 +30,12 @@ my @default_rules =
 
 sub rebuild(@)
 {   my ($self, %args) = @_;
- 
-    # Collect the rules to be run
+    my $keep  = delete $args{keep_message_id};
 
-    my @rules   = $args{rules} ? @{$args{rules}} : @default_rules;
-    unshift @rules, @{$args{extra_rules}} if $args{extra_rules};
-    unshift @rules, @{$args{extraRules}}  if $args{extraRules}; #old name
+    # Collect the rules to be run
+    my @rules = $args{rules} ? @{delete $args{rules}} : @default_rules;
+    unshift @rules, @{delete $args{extra_rules}} if $args{extra_rules};
+    unshift @rules, @{delete $args{extraRules}}  if $args{extraRules}; #old name
 
     foreach my $rule (@rules)
     {   next if ref $rule;
@@ -47,7 +47,7 @@ sub rebuild(@)
 
     # Start off with the message
 
-    my $rebuild = $self->recursiveRebuildPart($self, rules => \@rules)
+    my $rebuild = $self->recursiveRebuildPart($self, %args, rules => \@rules)
         or return;
 
     # Be sure we end-up with a message
@@ -60,7 +60,7 @@ sub rebuild(@)
         $rebuild = $clone;
     }
 
-    $args{keep_message_id} or $rebuild->takeMessageId;
+    $keep or $rebuild->takeMessageId;
     $rebuild;
 }
 
@@ -142,7 +142,7 @@ sub descendMultiparts($@)
 
     $rebuild->body($newbody);   # update Content-* lines
     $rebuild;
- }
+}
 
 sub descendNested($@)
 {   my ($self, $part, %args) = @_;
@@ -189,7 +189,7 @@ sub replaceDeletedParts($@)
 # The more complex rules
 
 sub removeHtmlAlternativeToText($@)
-{   my ($self, $part, %args) = @_;
+{   my ($self, $part) = @_;
     $part->body->mimeType eq 'text/html'
         or return $part;
 
@@ -208,7 +208,7 @@ sub removeHtmlAlternativeToText($@)
 }
 
 sub removeExtraAlternativeText($@)
-{   my ($self, $part, %args) = @_;
+{   my ($self, $part) = @_;
 
     my $container = $part->container;
     $container && $container->mimeType eq 'multipart/alternative'
@@ -225,7 +225,7 @@ sub textAlternativeForHtml($@)
 
     my $hft = 'Mail::Message::Convert::HtmlFormatText';
     unless(defined $has_hft)
-    {   eval "require Mail::Message::Convert::HtmlFormatText";
+    {   eval "require $hft";
         $has_hft = $hft->can('format');
     }
 
@@ -244,7 +244,7 @@ sub textAlternativeForHtml($@)
     # Create the plain part
 
     my $html_body  = $part->body;
-    my $plain_body = $hft->new->format($html_body);
+    my $plain_body = $hft->new(%args)->format($html_body);
 
     my $plain_part = Mail::Message::Part->new(container => undef);
     $plain_part->body($plain_body);
@@ -280,7 +280,8 @@ sub recursiveRebuildPart($@)
 
   RULES:
     foreach my $rule (@{$args{rules}})
-    {   my $rebuild = $self->$rule($part, %args)
+    {   my %params  = ( %args, %{$args{$rule} || {}} );
+        my $rebuild = $self->$rule($part, %params)
             or return undef;
 
         if($part != $rebuild)
